An integer. The maximum number of elements to show for each column.
If NULL or 0, show all elements, not recommended due to huge memory waste.
random_sample
A logical value. If TRUE, randomly sample the elements to show.
long_df
A logical value. If TRUE, the input df is provided in a long format.
subject_col
A character string. The name of the column that contains the subject
identifier. Used when long_df is TRUE.
If NULL, the subject column is assumed to be the first column.
value_col
A character string. The name of the column that contains the values.
Used when long_df is TRUE.
If NULL, the value column is assumed to be the second column.