Learn R Programming

clinpubr (version 1.1.1)

max_missing_rates: Get the maximum missing rate of rows and columns.

Description

Get the maximum missing rate of rows and columns.

Usage

max_missing_rates(df)

Value

A list that contains the maximum missing rate of rows and columns.

Arguments

df

A data frame.

Examples

Run this code
data(cancer, package = "survival")
max_missing_rates(cancer)

Run the code above in your browser using DataLab