merge_ordered_vectors: Merging vectors while maintaining order
Description
Merge multiple vectors into one while trying to maintain
the order of elements in each vector. The relative order of elements
is compared by their first occurrence in the vectors in the list.
This function is useful when merging slightly different vectors,
such as questionnaires of different versions.