powered by
Get the maximum missing rate of rows and columns.
max_missing_rates(df)
A list that contains the maximum missing rate of rows and columns.
A data frame.
data(cancer, package = "survival") max_missing_rates(cancer)
Run the code above in your browser using DataLab